#romanization
class AmharicRomanizer:
    def romanize (norm):
        norm = norm.replace("ሀ", "ha")
        norm = norm.replace("ሁ", "hu")
        norm = norm.replace("ሂ", "hi")
        norm = norm.replace("ሃ", "hā")
        norm = norm.replace("ሄ", "hé")
        norm = norm.replace("ህ", "h")
        norm = norm.replace("ሆ", "ho")
        norm = norm.replace("ለ", "la")
        norm = norm.replace("ሉ", "lu")
        norm = norm.replace("ሊ", "li")
        norm = norm.replace("ላ", "lā")
        norm = norm.replace("ሌ", "lé")
        norm = norm.replace("ል", "l")
        norm = norm.replace("ሎ", "lo")
        norm = norm.replace("ሏ", "lwa")
        norm = norm.replace("ሐ", "ḥa")
        norm = norm.replace("ሑ", "ḥu")
        norm = norm.replace("ሒ", "ḥi")
        norm = norm.replace("ሓ", "ḥā")
        norm = norm.replace("ሔ", "ḥé")
        norm = norm.replace("ሕ", "ḥ")
        norm = norm.replace("ሖ", "ḥo")
        norm = norm.replace("ሗ", "hwa")
        norm = norm.replace("መ", "mä")
        norm = norm.replace("ሙ", "mu")
        norm = norm.replace("ሚ", "mi")
        norm = norm.replace("ማ", "mā")
        norm = norm.replace("ሜ", "mé")
        norm = norm.replace("ም", "m")
        norm = norm.replace("ሞ", "mo")
        norm = norm.replace("ሟ", "mwa")
        norm = norm.replace("ሠ", "śa")
        norm = norm.replace("ሡ", "śu")
        norm = norm.replace("ሢ", "śi")
        norm = norm.replace("ሣ", "śā")
        norm = norm.replace("ሤ", "śé")
        norm = norm.replace("ሥ", "ś")
        norm = norm.replace("ሦ", "śo")
        norm = norm.replace("ሧ", "śwa")
        norm = norm.replace("ረ", "ra")
        norm = norm.replace("ሩ", "ru")
        norm = norm.replace("ሪ", "ri")
        norm = norm.replace("ራ", "rā")
        norm = norm.replace("ሬ", "ré")
        norm = norm.replace("ር", "r")
        norm = norm.replace("ሮ", "ro")
        norm = norm.replace("ሯ", "rwa")
        norm = norm.replace("ሰ", "sa")
        norm = norm.replace("ሱ", "su")
        norm = norm.replace("ሲ", "si")
        norm = norm.replace("ሳ", "sā")
        norm = norm.replace("ሴ", "sé")
        norm = norm.replace("ስ", "sə")
        norm = norm.replace("ሶ", "so")
        norm = norm.replace("ሷ", "swa")
        norm = norm.replace("ሸ", "ša")
        norm = norm.replace("ሹ", "šu")
        norm = norm.replace("ሺ", "ši")
        norm = norm.replace("ሻ", "šā")
        norm = norm.replace("ሼ", "šé")
        norm = norm.replace("ሽ", "š")
        norm = norm.replace("ሾ", "šo")
        norm = norm.replace("ሿ", "šwa")
        norm = norm.replace("ቀ", "qa")
        norm = norm.replace("ቁ", "qu")
        norm = norm.replace("ቂ", "qi")
        norm = norm.replace("ቃ", "qā")
        norm = norm.replace("ቄ", "qé")
        norm = norm.replace("ቅ", "q")
        norm = norm.replace("ቆ", "qo")
        norm = norm.replace("ቈ", "qwa")
        norm = norm.replace("ቊ", "qwu")
        norm = norm.replace("ቋ", "qwi")
        norm = norm.replace("ቌ", "qwā")
        norm = norm.replace("ቍ", "qwe")
        norm = norm.replace("በ", "ba")
        norm = norm.replace("ቡ", "bu")
        norm = norm.replace("ቢ", "bi")
        norm = norm.replace("ባ", "bā")
        norm = norm.replace("ቤ", "bé")
        norm = norm.replace("ብ", "b")
        norm = norm.replace("ቦ", "bo")
        norm = norm.replace("ቧ", "bwa")
        norm = norm.replace("ቨ", "va")
        norm = norm.replace("ቩ", "vu")
        norm = norm.replace("ቪ", "vi")
        norm = norm.replace("ቫ", "vā")
        norm = norm.replace("ቬ", "vé")
        norm = norm.replace("ቭ", "v")
        norm = norm.replace("ቮ", "vo")
        norm = norm.replace("ቯ", "vwa")
        norm = norm.replace("ተ", "ta")
        norm = norm.replace("ቱ", "tu")
        norm = norm.replace("ቲ", "ti")
        norm = norm.replace("ታ", "tā")
        norm = norm.replace("ቴ", "té")
        norm = norm.replace("ት", "t")
        norm = norm.replace("ቶ", "to")
        norm = norm.replace("ቷ", "twa")
        norm = norm.replace("ቸ", "ča")
        norm = norm.replace("ቹ", "ču")
        norm = norm.replace("ቺ", "či")
        norm = norm.replace("ቻ", "čā")
        norm = norm.replace("ቼ", "čé")
        norm = norm.replace("ች", "č")
        norm = norm.replace("ቾ", "čo")
        norm = norm.replace("ቿ", "čwa")
        norm = norm.replace("ኀ", "ẖa")
        norm = norm.replace("ኁ", "ẖu")
        norm = norm.replace("ኂ", "ẖi")
        norm = norm.replace("ኃ", "ẖā")
        norm = norm.replace("ኄ", "ẖé")
        norm = norm.replace("ኅ", "ẖ")
        norm = norm.replace("ኆ", "ẖo")
        norm = norm.replace("ኈ", "ẖwa")
        norm = norm.replace("ኊ", "ẖwi")
        norm = norm.replace("ኋ", "ẖwā")
        norm = norm.replace("ኌ", "ẖwé")
        norm = norm.replace("ኍ", "ẖwe")
        norm = norm.replace("ነ", "na")
        norm = norm.replace("ኑ", "nu")
        norm = norm.replace("ኒ", "ni")
        norm = norm.replace("ና", "nā")
        norm = norm.replace("ኔ", "né ")
        norm = norm.replace("ን", "n")
        norm = norm.replace("ኖ", "no")
        norm = norm.replace("ኗ", "nwa")
        norm = norm.replace("ኘ", "ña")
        norm = norm.replace("ኙ", "ñu")
        norm = norm.replace("ኚ", "ñi")
        norm = norm.replace("ኛ", "ñā")
        norm = norm.replace("ኜ", "ñé")
        norm = norm.replace("ኝ", "ñ")
        norm = norm.replace("ኞ", "ño")
        norm = norm.replace("ኟ", "ñwa")
        norm = norm.replace("አ", "ʾa")
        norm = norm.replace("ኡ", "ʾu")
        norm = norm.replace("ኢ", "ʾi")
        norm = norm.replace("ኣ", "ʾā")
        norm = norm.replace("ኤ", "ʾé")
        norm = norm.replace("እ", "ʾe")
        norm = norm.replace("ኦ", "ʾo")
        norm = norm.replace("ኧ", "ă")
        norm = norm.replace("ከ", "ka")
        norm = norm.replace("ኩ", "ku")
        norm = norm.replace("ኪ", "ki")
        norm = norm.replace("ካ", "kā")
        norm = norm.replace("ኬ", "ké")
        norm = norm.replace("ክ", "k")
        norm = norm.replace("ኮ", "ko")
        norm = norm.replace("ኰ", "kwa")
        norm = norm.replace("ኲ", "kwi")
        norm = norm.replace("ኳ", "kwā")
        norm = norm.replace("ኴ", "kwé")
        norm = norm.replace("ኵ", "kwe")
        norm = norm.replace("ኸ", "xa")
        norm = norm.replace("ኹ", "xu")
        norm = norm.replace("ኺ", "xi")
        norm = norm.replace("ኻ", "xā")
        norm = norm.replace("ኼ", "xé")
        norm = norm.replace("ኽ", "x")
        norm = norm.replace("ኾ", "xo")
        norm = norm.replace("ወ", "wa")
        norm = norm.replace("ዉ", "wu")
        norm = norm.replace("ዊ", "wi")
        norm = norm.replace("ዋ", "wā")
        norm = norm.replace("ዌ", "wé")
        norm = norm.replace("ው", "w")
        norm = norm.replace("ዎ", "wo")
        norm = norm.replace("ዐ", "ʻa")
        norm = norm.replace("ዑ", "ʻu")
        norm = norm.replace("ዒ", "ʻi")
        norm = norm.replace("ዓ", "ʻā")
        norm = norm.replace("ዔ", "ʻé")
        norm = norm.replace("ዕ", "ʻe")
        norm = norm.replace("ዖ", "ʻo")
        norm = norm.replace("ዘ", "za")
        norm = norm.replace("ዙ", "zu")
        norm = norm.replace("ዚ", "zi")
        norm = norm.replace("ዛ", "zā")
        norm = norm.replace("ዜ", "zé")
        norm = norm.replace("ዝ", "z")
        norm = norm.replace("ዞ", "zo")
        norm = norm.replace("ዟ", "zwa")
        norm = norm.replace("ዠ", "ža")
        norm = norm.replace("ዡ", "žu")
        norm = norm.replace("ዢ", "ži")
        norm = norm.replace("ዣ", "žā")
        norm = norm.replace("ዤ", "žé")
        norm = norm.replace("ዥ", "ž")
        norm = norm.replace("ዦ", "žo")
        norm = norm.replace("ዧ", "žwa")
        norm = norm.replace("የ", "ya")
        norm = norm.replace("ዩ", "yu")
        norm = norm.replace("ዪ", "yi")
        norm = norm.replace("ያ", "yā")
        norm = norm.replace("ዬ", "yé")
        norm = norm.replace("ይ", "y")
        norm = norm.replace("ዮ", "yo")
        norm = norm.replace("ደ", "da")
        norm = norm.replace("ዱ", "du")
        norm = norm.replace("ዲ", "di")
        norm = norm.replace("ዳ", "dā")
        norm = norm.replace("ዴ", "dé")
        norm = norm.replace("ድ", "d")
        norm = norm.replace("ዶ", "do")
        norm = norm.replace("ዷ", "dwa")
        norm = norm.replace("ጀ", "ǧa")
        norm = norm.replace("ጁ", "ǧu")
        norm = norm.replace("ጂ", "ǧi")
        norm = norm.replace("ጃ", "ǧā")
        norm = norm.replace("ጄ", "ǧé")
        norm = norm.replace("ጅ", "ǧ")
        norm = norm.replace("ጆ", "ǧo")
        norm = norm.replace("ጇ", "ǧwa")
        norm = norm.replace("ገ", "ga")
        norm = norm.replace("ጉ", "gu")
        norm = norm.replace("ጊ", "gi")
        norm = norm.replace("ጋ", "gā")
        norm = norm.replace("ጌ", "gé")
        norm = norm.replace("ግ", "g")
        norm = norm.replace("ጎ", "go")
        norm = norm.replace("ጐ", "gwa")
        norm = norm.replace("ጒ", "gwi")
        norm = norm.replace("ጓ", "gwā")
        norm = norm.replace("ጔ", "gwé")
        norm = norm.replace("ጕ", "gwe")
        norm = norm.replace("ጠ", "ṭa")
        norm = norm.replace("ጡ", "ṭu")
        norm = norm.replace("ጢ", "ṭi")
        norm = norm.replace("ጣ", "ṭā")
        norm = norm.replace("ጤ", "ṭé")
        norm = norm.replace("ጥ", "ṭ")
        norm = norm.replace("ጦ", "ṭo")
        norm = norm.replace("ጧ", "ṭwā")
        norm = norm.replace("ጨ", "ċa")
        norm = norm.replace("ጩ", "ċu")
        norm = norm.replace("ጪ", "ċi")
        norm = norm.replace("ጫ", "ċā")
        norm = norm.replace("ጬ", "ċé")
        norm = norm.replace("ጭ", "ċ")
        norm = norm.replace("ጮ", "ċo")
        norm = norm.replace("ጯ", "ċwā")
        norm = norm.replace("ጰ", "p̣a")
        norm = norm.replace("ጱ", "p̣u")
        norm = norm.replace("ጲ", "p̣i")
        norm = norm.replace("ጳ", "p̣ā")
        norm = norm.replace("ጴ", "p̣é")
        norm = norm.replace("ጵ", "p̣")
        norm = norm.replace("ጶ", "p̣o")
        norm = norm.replace("ጷ", "p̣wa")
        norm = norm.replace("ጸ", "ṣa")
        norm = norm.replace("ጹ", "ṣu")
        norm = norm.replace("ጺ", "ṣi")
        norm = norm.replace("ጻ", "ṣā")
        norm = norm.replace("ጼ", "ṣé")
        norm = norm.replace("ጽ", "ṣ")
        norm = norm.replace("ጾ", "ṣo")
        norm = norm.replace("ጿ", "ṣwā")
        norm = norm.replace("ፀ", "ṡa")
        norm = norm.replace("ፁ", "ṡu")
        norm = norm.replace("ፂ", "ṡi")
        norm = norm.replace("ፃ", "ṡā")
        norm = norm.replace("ፄ", "ṡé")
        norm = norm.replace("ፅ", "ṡ")
        norm = norm.replace("ፆ", "ṡo")
        norm = norm.replace("ፈ", "fa")
        norm = norm.replace("ፉ", "fu")
        norm = norm.replace("ፊ", "fi")
        norm = norm.replace("ፋ", "fā")
        norm = norm.replace("ፌ", "fé")
        norm = norm.replace("ፍ", "f")
        norm = norm.replace("ፎ", "fo")
        norm = norm.replace("ፏ", "fwā")
        norm = norm.replace("ፐ", "pa")
        norm = norm.replace("ፑ", "pu")
        norm = norm.replace("ፒ", "pi")
        norm = norm.replace("ፓ", "pā")
        norm = norm.replace("ፔ", "pé")
        norm = norm.replace("ፕ", "p")
        norm = norm.replace("ፖ", "po")
        norm = norm.replace("ፗ", "pwa")
        norm = norm.replace("፡", " ")
        norm = norm.replace("።", ".")
        norm = norm.replace("፡፡", ".")
        norm = norm.replace("፤", ";")
        norm = norm.replace("፥", ":")
        norm = norm.replace("፣", ",")
        norm = norm.replace("፧", ".")
        norm = norm.replace("፩", "1")
        norm = norm.replace("፪", "2")
        norm = norm.replace("፫", "3")
        norm = norm.replace("፬", "4")
        norm = norm.replace("፭", "5")
        norm = norm.replace("፮", "6")
        norm = norm.replace("፯", "7")
        norm = norm.replace("፰", "8")
        norm = norm.replace("፱", "9")
        norm = norm.replace("፲", "10")
        norm = norm.replace("፳", "20")
        norm = norm.replace("፴", "30")
        norm = norm.replace("፵", "40")
        norm = norm.replace("፶", "50")
        norm = norm.replace("፷", "60")
        norm = norm.replace("፸", "70")
        norm = norm.replace("፹", "80")
        norm = norm.replace("፺", "90")
        norm = norm.replace("፻", "100")
        norm = norm.replace("\n", "\n")
        return norm